@@ -48,7 +48,7 @@ sidra_download <- function(sidra_code = NULL, year, geo_level = "municipality",
   ## Get Geographical Information ##
   ##################################
 
-  geo <- municipalities %>%
+  geo <- datazoom.amazonia::municipalities %>%
     tidyr::drop_na() # 5 municipalities have no micro code
 
   # uf = list('RO' = 11,'AC' = 12,'AM' = 13,'RR' = 14,'PA' = 15,'AP' = 16,'TO' = 17,
@@ -276,31 +276,32 @@ sidra_download <- function(sidra_code = NULL, year, geo_level = "municipality",
 }
 
 external_download <- function(dataset = NULL, source = NULL, year = NULL,
-                              geo_level = NULL, coords = NULL, dataset_code = NULL) {
+                              geo_level = NULL, coords = NULL, dataset_code = NULL,
+                              sheet = NULL, skip_rows = NULL, file_name = NULL,
+                              state = NULL) {
 
-  ## Bind GLobal Variables
+  ## Bind Global Variables
 
   link <- NULL
 
-  # Need to Check Mapbiomas, Prodes and Comex
-
-  # ----------------------
-  # To Do:
-  # - Insert Error Message when user gives a wrong input
-  # ----------------------
-
   ## Define Basic Parameters
 
   param <- list()
   param$dataset <- dataset
   param$source <- source
-  param$year <- year # This may not make sense if data is downloaded for all time periods together
-  param$geo_level <- geo_level # This could also not make sense
+
+  # Optional parameters for functions that need them:
+
+  param$year <- year # if download is perform separately by year
+  param$geo_level <- geo_level # if some geo_levels have a different download link
   param$coords <- coords
   param$dataset_code <- dataset_code
+  param$skip_rows <- skip_rows # number of rows to skip atop a spreadsheet
+  param$file_name <- file_name
+  param$sheet <- sheet # which sheet of a .xlsx to read
+  param$state <- state
 
-  # if (param$geo_level == 'legal_amazon' & param$source == 'prodes'){param$geo_level = 'legal-amz-prodes'}
-  # if (param$geo_level == 'amazon_biome' & param$source == 'prodes'){param$geo_level = 'amz-prodes'}
+  if (is.null(param$skip_rows)) param$skip_rows <- 0 # makes it more error-proof
 
   ## Create Basic Url
 
@@ -316,16 +317,20 @@ external_download <- function(dataset = NULL, source = NULL, year = NULL,
   ## Construct Links ##
   #####################
 
-  ###########
-  ## Comex ##
-  ###########
+  # For most sources, the URL in datasets_link is already the URL needed for the download
 
-  # 2014 Examples
-  # https://balanca.economia.gov.br/balanca/bd/comexstat-bd/ncm/EXP_2014.csv
-  # https://balanca.economia.gov.br/balanca/bd/comexstat-bd/ncmv2/IMP_2014_V2.csv
-  # https://balanca.economia.gov.br/balanca/bd/comexstat-bd/mun/EXP_2014_MUN.csv
-  # https://balanca.economia.gov.br/balanca/bd/comexstat-bd/mun/IMP_2014_MUN.csv
+  path <- param$url
 
+  # Below are the exceptions, for which manipulation is needed
+
+  ##### Exceptions only #####
+
+  # If the datasets_link URL is the download path you need,
+  # do not change this section for a new function
+
+  ## Comex
+
+  # Download path depends on the dataset and year
 
   if (source == "comex") {
     if (dataset == "comex_export_mun") {
@@ -342,41 +347,18 @@ external_download <- function(dataset = NULL, source = NULL, year = NULL,
     }
   }
 
-  ############
-  ## Prodes ##
-  ############
+  ## Prodes
 
-  # http://www.dpi.inpe.br/prodesdigital/tabelatxt.php?ano=2020&estado=&ordem=MUNICIPIO&type=tabela&output=txt&
+  # Download path depends on the year
 
   if (source == "prodes") {
     path <- paste(param$url, "/tabelatxt.php?ano=", param$year, "&estado=&ordem=MUNICIPIO&type=tabela&output=txt&", sep = "")
   }
 
-  # Create a previous if for termination of file (vector .shp)
 
-  # if (source == 'prodes'){
-  #   if (dataset == 'prodes_accum_deforestation'){path = paste(param$url,param$geo_level,'vector/accumulated_deforestation_1988_2007.zip',sep='/')}
-  #   if (dataset == 'prodes_annual_increase_deforestation'){path = paste(param$url,param$geo_level,'vector/yearly_deforestation.zip',sep='/')}
-  #   if (dataset == 'prodes_cloud'){path = paste(param$url,param$geo_level,'vector/cloud.zip',sep='/')}
-  #   if (dataset == 'prodes_forest'){path = paste(param$url,param$geo_level,'vector/forest.zip',sep='/')}
-  #   if (dataset == 'prodes_hydrography'){path = paste(param$url,param$geo_level,'vector/hydrography.zip',sep='/')}
-  #   if (dataset == 'prodes_not_forest'){path = paste(param$url,param$geo_level,'vector/no_forest.zip',sep='/')}
-  # }
+  ## Degrad
 
-  ###########
-  ## Deter ##
-  ###########
-
-  # # Amazonia Legal = legal-amz-prodes
-  # Bioma Amazonia = amz-prodes
-
-  if (source == "deter") {
-    path <- paste(param$url, stringr::str_replace(param$dataset, "_", "-"), "/shape", sep = "")
-  }
-
-  ############
-  ## Degrad ##
-  ############
+  # Download path depends on the year
 
   if (source == "degrad") {
     if (dataset == "degrad") {
@@ -384,24 +366,18 @@ external_download <- function(dataset = NULL, source = NULL, year = NULL,
     }
   }
 
-  ###############
-  ## MapBiomas ##
-  ###############
-
-  # https://mapbiomas-br-site.s3.amazonaws.com/Estat%C3%ADsticas/Dados_Cobertura_MapBiomas_5.0_UF-BIOMAS_SITE.xlsx
-  # https://mapbiomas-br-site.s3.amazonaws.com/Estat%C3%ADsticas/Dados_Cobertura_MapBiomas_5.0_UF-MUN_SITE_v2.xlsx
-  # https://storage.googleapis.com/mapbiomas-public/COLECAO/5/DOWNLOADS/ESTATISTICAS/Dados_Transicao_MapBiomas_5.0_UF-MUN_SITE_v2.xlsx
-  # https://mapbiomas-br-site.s3.amazonaws.com/Estat%C3%ADsticas/BD-DESM_e_REG_COL5_V8h__SITE.xlsx
-  # https://mapbiomas-br-site.s3.amazonaws.com/Estat%C3%ADsticas/MapBIomas_COL5_IRRIGACAO-biomas-estados-SITE.xlsx
-  # https://mapbiomas-br-site.s3.amazonaws.com/Estat%C3%ADsticas/MapBIomas_COL5_QUALIDADE_PASTAGEM-biomas-estados-SITE.xlsx
+  ## MapBiomas
 
+  # Download path depends on dataset and geo_level
 
   if (source == "mapbiomas") {
-    if (dataset == "mapbiomas_cover") {
-      path <- paste(param$url, "Estat%C3%ADsticas/Dados_Cobertura_MapBiomas_5.0_UF-MUN_SITE_v2.xlsx", sep = "")
-    }
-    if (dataset == "mapbiomas_transition") {
-      path <- "https://storage.googleapis.com/mapbiomas-public/COLECAO/5/DOWNLOADS/ESTATISTICAS/Dados_Transicao_MapBiomas_5.0_UF-MUN_SITE_v2.xlsx"
+    if (dataset %in% c("mapbiomas_cover", "mapbiomas_transition")) {
+      if (param$geo_level == "state") {
+        path <- paste(param$url, "Estat%C3%ADsticas/Cole%C3%A7%C3%A3o%206/1-ESTATISTICAS_MapBiomas_COL6.0_UF-BIOMAS_v12_SITE.xlsx", sep = "")
+      }
+      if (param$geo_level == "municipality") {
+        path <- "https://drive.google.com/uc?export=download&id=1RT7J2jS6LKyISM49ctfRO31ynJZXX_TY"
+      }
     }
     if (dataset == "mapbiomas_deforestation_regeneration") {
       path <- paste(param$url, "Estat%C3%ADsticas/BD-DESM_e_REG_COL5_V8h__SITE.xlsx", sep = "")
@@ -412,21 +388,14 @@ external_download <- function(dataset = NULL, source = NULL, year = NULL,
     if (dataset == "mapbiomas_grazing_quality") {
       path <- paste(param$url, "Estat%C3%ADsticas/MapBIomas_COL5_QUALIDADE_PASTAGEM-biomas-estados-SITE.xlsx", sep = "")
     }
-  }
-
-  #############
-  ## SIGMINE ##
-  #############
-
-  if (source == "sigmine") {
-    if (dataset == "sigmine_active") {
-      path <- paste(param$url, "SIGMINE/PROCESSOS_MINERARIOS/BRASIL.zip", sep = "")
+    if (dataset == "mapbiomas_mining") {
+      path <- paste(param$url, "Estat%C3%ADsticas/Cole%C3%A7%C3%A3o%206/Colecao_6_Mining_BR_UF_Biome_Mun_TI_SITE.xlsx", sep = "")
     }
   }
 
-  ##########
-  ## SEEG ##
-  ##########
+  ## SEEG
+
+  # Download path depends on geo_level
 
   if (source == "seeg") {
     if (geo_level == "municipality") {
@@ -437,27 +406,23 @@ external_download <- function(dataset = NULL, source = NULL, year = NULL,
     }
   }
 
-  #########
-  ## IPS ##
-  #########
+  ## IBAMA
 
-  if (source == "ips") {
-    path <- paste(param$url, "/assets/IPS_Tabela_Completa-1df30fcea79209e3c7e8634a586f95e6.xlsx", sep = "")
-  }
-
-  ###########
-  ## IBAMA ##
-  ###########
+  # Download path depends on state
 
   if (source == "ibama") {
     if (dataset == "areas_embargadas") {
       path <- param$url
+    } else if (dataset == "distributed_fines") {
+      path <- paste0(param$url, param$state, "/Quantidade/multasDistribuidasBensTutelados.csv")
+    } else if (dataset == "collected_fines") {
+      path <- paste0(param$url, param$state, "/Arrecadacao/arrecadacaobenstutelados.csv")
     }
   }
 
-  ##################
-  ## TerraClimate ##
-  ##################
+  ## TerraClimate
+
+  # Download path depends on geographical parameters
 
   if (source == "terraclimate") {
     filename <- paste0(
@@ -491,79 +456,131 @@ external_download <- function(dataset = NULL, source = NULL, year = NULL,
     )
   }
 
-  #####################
-  ## GeoBR Shapefile ##
-  #####################
+  ## Datasus
 
-  if (source == "internal") {
-    if (dataset == "geo_municipalities") {
-      path <- param$url
-    }
+  # Download path depends on the specific file wanted
+
+  if (source == "datasus") {
+    path <- paste0(param$url, param$file_name)
   }
 
   #######################
   ## Initiate Download ##
   #######################
 
-  ## We should be careful when the downloaded files is terminated in .xlsx
+  ## Specify file extension to be passed to tempfile()
 
-  file_extension <- stringr::str_sub(path, -4)
-  if (source == "mapbiomas") {
-    file_extension <- ".xlsx"
+  # For most functions, the file extension is automatically detected
+
+  file_extension <- sub(".*\\.", ".", path)
+
+  ##### Exceptions only #####
+
+  # Only manually input the file_extension if the download_path does
+  # not end in ".ext", where .ext is any file extension
+
+  # googledrive links do not contain the file extension, for example
+
+  if (source == "mapbiomas" & dataset %in% c("mapbiomas_cover", "mapbiomas_transition")) {
+    if (param$geo_level == "municipality") {
+      file_extension <- ".zip"
+    }
   }
-  if (source == "ips") {
-    file_extension <- ".xlsx"
+  if (source == "cipo") {
+    file_extension <- ".csv"
   }
   if (source == "prodes") {
     file_extension <- ".txt"
   }
-  if (source == "deter") {
-    file_extension <- ".zip"
-  }
-  if (source == "seeg") {
+  if (source %in% c("seeg", "iema")) {
     file_extension <- ".xlsx"
   }
-  if (source == "ibama") {
-    file_extension <- ".zip"
-  }
   if (source == "terraclimate") {
     file_extension <- ".nc"
   }
-  if (source == "internal") {
+  if (source == "deter") {
+    file_extension <- ".zip"
+  }
+  if (source == "ibama") {
+    if (dataset == "areas_embargadas") {
+      file_extension <- ".zip"
+    } else {
+      file_extension <- ".csv"
+    }
+  }
+  if (source == "imazon_shp") {
     file_extension <- ".rds"
   }
-
-  # !!!  We should Change This to a Curl Process
+  if (source == "EPE") {
+    if (param$dataset == "national_energy_balance") {
+      file_extension <- ".csv"
+    }
+  }
+  if (source == "ANEEL") {
+    if (dataset == "energy_development_budget") {
+      file_extension <- ".rds"
+    }
+    if (dataset == "energy_generation") {
+      file_extension <- ".xlsx"
+    }
+  }
 
   ## Define Empty Directory and Files For Download
 
   dir <- tempdir()
   temp <- tempfile(fileext = file_extension, tmpdir = dir)
 
-  ## Extraction through Curl Requests
-  ## Investigate a bit more on how Curl Requests work
+  ## Picking the way to download the file
 
-  if (!(source %in% c("deter", "seeg", "terraclimate"))) {
-    utils::download.file(url = path, destfile = temp, mode = "wb")
+  download_method <- "standard" # works for most functions
+
+  if (source %in% c("iema", "imazon_shp")) {
+    download_method <- "googledrive"
   }
-  if (source == "deter") {
-    proc <- RCurl::CFILE(temp, mode = "wb")
-    RCurl::curlPerform(url = path, writedata = proc@ref, noprogress = FALSE)
-    RCurl::close(proc)
+  if (source == "ANEEL") {
+    if (dataset == "energy_development_budget") {
+      download_method <- "googledrive"
+    }
+  }
+  if (source == "EPE") {
+    if (dataset == "national_energy_balance") {
+      download_method <- "googledrive"
+    }
+  }
+  if (source %in% c("deter", "terraclimate", "baci")) {
+    download_method <- "curl"
+    quiet <- FALSE
+  }
+  if (source %in% c("ibama", "datasus")) {
+    download_method <- "curl"
+    quiet <- TRUE
   }
   if (source == "seeg") {
-    if (geo_level == "state" | geo_level == "country") {
-      utils::download.file(url = path, destfile = temp, mode = "wb")
-    }
     if (geo_level == "municipality") {
-      googledrive::drive_download(path, path = temp, overwrite = TRUE)
+      download_method <- "googledrive"
     }
   }
-  if (source == "terraclimate") {
-    utils::download.file(url = path, destfile = temp, method = "curl")
+  if (source == "mapbiomas") {
+    if (dataset %in% c("mapbiomas_cover", "mapbiomas_transition") & param$geo_level == "municipality") {
+      download_method <- "googledrive"
+    }
   }
 
-  ## This Data Opening Part Should Include the .Shp, not DBF
+  ## Downloading file by the selected method
+
+  if (download_method == "standard") {
+    utils::download.file(url = path, destfile = temp, mode = "wb")
+  }
+  if (download_method == "curl") {
+    utils::download.file(url = path, destfile = temp, method = "curl", quiet = quiet)
+  }
+  if (download_method == "googledrive") {
+    message("Please follow the steps from `googledrive` package to download the data. This may take a while.\nIn case of authentication errors, run vignette(\"GOOGLEDRIVE\").")
+
+    googledrive::drive_download(path, path = temp, overwrite = TRUE)
+  }
+
+  ## Unzipping if the file is zipped
 
   if (file_extension == ".zip") {
     utils::unzip(temp, exdir = dir)
@@ -573,126 +590,20 @@ external_download <- function(dataset = NULL, source = NULL, year = NULL,
   ## Load Data ##
   ###############
 
-  # This Depends on Data Type (.csv, .shp, ...) and on datasource
 
-  # df = sf::read_sf(paste(dir, "deter_public.shp", sep = "/"))
-
-  if (file_extension == ".csv") {
-    dat <- data.table::fread(temp) %>% tibble::as_tibble()
-  }
-  if (file_extension == ".txt") {
-    dat <- readr::read_csv(temp, locale = readr::locale(encoding = "latin1")) %>%
-      janitor::clean_names() %>%
-      tibble::as_tibble()
-  }
-  if (file_extension == ".nc") {
-    dat <- terra::rast(temp)
-  }
-  if (file_extension == ".rds") {
-    dat <- readr::read_rds(temp)
-  }
-  if (file_extension == ".xlsx") {
-    if (param$dataset == "mapbiomas_cover") {
-      dat <- readxl::read_excel(temp, sheet = "LAND COVER - BIOMAS e UF")
-    } ## HA
-    if (param$dataset == "mapbiomas_transition") {
-      dat <- readxl::read_excel(temp, sheet = "BD_TRANSICAO_BIOMA-UF")
-    }
-    if (param$dataset == "mapbiomas_deforestation_regeneration") {
-      dat <- readxl::read_excel(temp, sheet = "BD Colecao 5.0(h) - Hectares")
-    }
-    if (param$dataset == "mapbiomas_irrigation") {
-      dat <- readxl::read_excel(temp, sheet = "BD_IRRIGACAO")
-    }
-    if (param$dataset == "mapbiomas_grazing_quality") {
-      dat <- readxl::read_excel(temp, sheet = "BD_Qualidade")
-    }
-
-    if (param$source == "seeg") {
-      if (geo_level == "country") {
-        dat <- readxl::read_excel(temp, sheet = "GEE Brasil")
-      }
-      if (geo_level == "state") {
-        dat <- readxl::read_excel(temp, sheet = "GEE Estados")
-      }
-      if (geo_level == "municipality") {
-        dat <- readxl::read_excel(temp, sheet = "BD GEE Municipios GWP-AR5")
-      }
-    }
-
-    if (param$dataset == "ips") {
-      if (param$year == 2014) {
-        dat <- readxl::read_excel(temp, sheet = "IPS 2014")
-      }
-      if (param$year == 2018) {
-        dat <- readxl::read_excel(temp, sheet = "IPS 2018 ")
-      }
-      if (param$year == 2021) {
-        dat <- readxl::read_excel(temp, sheet = "IPS 2021")
-      }
-    }
-
-
-
-    dat <- dat %>%
-      janitor::clean_names() %>%
-      tibble::as_tibble()
-  }
+  ##### Exceptions only #####
 
   if (file_extension == ".zip") {
     if (param$dataset == "degrad") {
-      if (param$year %in% 2007) {
-        dat <- sf::read_sf(paste(dir, "Degrad2007_Final_pol.shp", sep = "\\"))
-        dat$year <- param$year
-      }
-      if (param$year == 2008) {
-        dat <- sf::read_sf(paste(dir, "Degrad2008_Final_pol.shp", sep = "\\"))
-        dat$year <- param$year
-      }
-      if (param$year == 2009) {
-        dat <- sf::read_sf(paste(dir, "Degrad2009_Final_pol.shp", sep = "\\"))
-        dat$year <- param$year
-      }
-      if (param$year == 2010) {
-        dat <- sf::read_sf(paste(dir, "DEGRAD_2010_UF_pol.shp", sep = "\\"))
-        dat$year <- param$year
-      }
-      if (param$year == 2011) {
-        dat <- sf::read_sf(paste(dir, "DEGRAD_2011_INPE_pol.shp", sep = "\\"))
-        dat$year <- param$year
-      }
-      if (param$year == 2012) {
-        dat <- sf::read_sf(paste(dir, "DEGRAD_2012_INPE_pol.shp", sep = "\\"))
-        dat$year <- param$year
-      }
-      if (param$year == 2013) {
-        dat <- sf::read_sf(paste(dir, "DEGRAD_2013_INPE_pol.shp", sep = "\\"))
-        dat$year <- param$year
-      }
-      if (param$year == 2014) {
-        dat <- sf::read_sf(paste(dir, "DEGRAD_2014_pol.shp", sep = "\\"))
-        dat$year <- param$year
-      }
-      if (param$year == 2015) {
-        dat <- sf::read_sf(paste(dir, "DEGRAD_2015.shp", sep = "\\"))
-        dat$year <- param$year
-      }
-      if (param$year == 2016) {
-        dat <- sf::read_sf(paste(dir, "DEGRAD_2016_pol.shp", sep = "\\"))
-        dat$year <- param$year
-      }
+      dat <- sf::read_sf(file.path(dir, param$file_name))
+      dat$year <- param$year
     }
-
     if (param$source == "deter") {
-      dat <- sf::read_sf(paste(dir, "deter_public.shp", sep = "\\")) %>%
-        janitor::clean_names() %>%
-        tibble::as_tibble()
+      dat <- sf::read_sf(file.path(dir, "deter_public.shp"))
     }
-
     if (param$source == "sigmine") {
-      dat <- sf::read_sf(paste(dir, "BRASIL.shp", sep = "\\"))
+      dat <- sf::read_sf(file.path(dir, "BRASIL.shp"))
     }
-
     if (param$source == "ibama") {
 
       # get latest downloaded file (the name changes daily)
@@ -709,16 +620,86 @@ external_download <- function(dataset = NULL, source = NULL, year = NULL,
 
       colnames(dataset) <- dataset[5, ]
 
-      dat <- dataset[-c(1:5), ] %>%
-        janitor::clean_names() %>%
-        tibble::as_tibble()
+      dat <- dataset[-c(1:5), ]
+    }
+
+    if (param$source == "baci") {
+
+      # as year can be a vector, sets up expressions of the form "*YYYY_V202201.csv" for each year to match file names
+      file_expression <- paste0("*", param$year, "_V202201.csv")
+
+      # now turning into *XXXX_V202201.csv|YYYY_V202201.csv|ZZZZ_V202201.csv" to match as regex
+      file_expression <- paste0(file_expression, collapse = "|")
+
+      file <- list.files(dir, pattern = file_expression, full.names = TRUE) %>%
+        as.list()
+
+      # now reads each file
+      dat <- lapply(file, data.table::fread, header = TRUE, sep = ",")
+
+      # each data frame in the list is named after the corresponding year
+      names(dat) <- param$year
+    }
+
+    if (param$source == "mapbiomas") {
+
+      # extracting the one file we care about from the unzipped file
+      file <- list.files(dir, pattern = "1-ESTATISTICAS_MapBiomas_COL6.0_UF-MUNICIPIOS_*", full.names = TRUE)
+
+      dat <- readxl::read_xlsx(file, sheet = param$sheet)
     }
   }
 
-  # if (source == 'prodes'){
-  #   file = list.files(dir)[stringr::str_detect(list.files(dir),'.shp')]
-  #   dat = sf::read_sf(paste(dir,file,sep='\\'))
-  # }
+  if (param$source == "EPE" & param$dataset == "energy_consumption_per_class") {
+
+    # param$sheet contains the selected sheets
+
+    # Making a list with all the sheets
+    dat <- purrr::imap(
+      param$sheet,
+      function(sheets, number) {
+        base::message(
+          paste0("Reading sheet ", number, " out of ", length(param$sheet), " (", sheets, ")")
+        )
+        base::suppressMessages(
+          readxl::read_xls(temp, sheet = sheets)
+        )
+      }
+    )
+
+    names(dat) <- param$sheet
+  }
+  if (param$source == "ips") {
+    dat <- param$sheet %>%
+      purrr::map(
+        ~ readxl::read_xlsx(temp, sheet = .)
+      )
+  }
+
+  ## Now the rest of the functions
+
+  # This Depends on Data Type (.csv, .shp, ...) and on the data source
+
+  else {
+    if (file_extension == ".csv") {
+      dat <- data.table::fread(temp)
+    }
+    if (file_extension == ".txt") {
+      dat <- readr::read_csv(temp, locale = readr::locale(encoding = "latin1"))
+    }
+    if (file_extension == ".nc") {
+      dat <- terra::rast(temp)
+    }
+    if (file_extension == ".rds") {
+      dat <- readr::read_rds(temp)
+    }
+    if (file_extension == ".xlsx") {
+      dat <- readxl::read_xlsx(temp, sheet = param$sheet, skip = param$skip_rows)
+    }
+    if (file_extension == ".dbc") {
+      dat <- read.dbc(temp)
+    }
+  }
 
   ##############################
   ## Excluding Temporary File ##
@@ -730,13 +711,6 @@ external_download <- function(dataset = NULL, source = NULL, year = NULL,
     unlink(temp)
   }
 
-  ####################
-  ## Pre-Processing ##
-  ####################
-
-  # Prodes and Txt need to have year extracted + encoding ajusted
-
-
   #################
   ## Return Data ##
   #################
@@ -863,8 +837,6 @@ datasets_link <- function() {
     ## COMEX ##
     ###########
 
-    # https://www.gov.br/produtividade-e-comercio-exterior/pt-br/assuntos/comercio-exterior/estatisticas/base-de-dados-bruta
-
     "COMEX-EXP-PROD_NCM", "comex_export_prod", NA, "1997-2021", NA, "https://balanca.economia.gov.br/balanca/bd/comexstat-bd/ncm",
     "COMEX-IMP-PROD_NCM", "comex_import_prod", NA, "1997-2021", NA, "https://balanca.economia.gov.br/balanca/bd/comexstat-bd/ncm",
     "COMEX-EXP-MUNIC_FIRM", "comex_export_mun", NA, "1997-2021", NA, "https://balanca.economia.gov.br/balanca/bd/comexstat-bd/mun",
@@ -874,54 +846,9 @@ datasets_link <- function() {
     ## INPE ##
     ##########
 
-    # Todos os Biomas
-
-    # We can include CAR as well
-
-    # PRODES
-
-    # http://www.obt.inpe.br/OBT/assuntos/programas/amazonia/prodes
-    # http://www.dpi.inpe.br/prodesdigital/prodesmunicipal.php
-    # http://www.dpi.inpe.br/prodesdigital/tabelatxt.php?ano=2020&estado=&ordem=MUNICIPIO&type=tabela&output=txt&
-
-    # Desmatamento Acumulado -http://terrabrasilis.dpi.inpe.br/download/dataset/legal-amz-prodes/vector/accumulated_deforestation_1988_2007.zip
-    # Floresta Anual - http://terrabrasilis.dpi.inpe.br/download/dataset/legal-amz-prodes/vector/forest.zip
-    # Hidrografia - http://terrabrasilis.dpi.inpe.br/download/dataset/legal-amz-prodes/vector/hydrography.zip
-    # Incremento Anual do Desmatamento - http://terrabrasilis.dpi.inpe.br/download/dataset/legal-amz-prodes/vector/yearly_deforestation.zip
-    # PRODES Completo - http://terrabrasilis.dpi.inpe.br/download/dataset/legal-amz-prodes/raster/PDigital2000_2020_AMZ_raster_v20210521.zip
-    # Nao Floresta - http://terrabrasilis.dpi.inpe.br/download/dataset/legal-amz-prodes/vector/cloud.zip
-
     "PRODES-INPE", "prodes", NA, "2000-2020", NA, "http://www.dpi.inpe.br/prodesdigital",
-    # 'PRODES-INPE','prodes_accum_deforestation',NA,'1988-2007',NA,'http://terrabrasilis.dpi.inpe.br/download/dataset',
-    # 'PRODES-INPE','prodes_forest',NA,'2016-2019',NA,'http://terrabrasilis.dpi.inpe.br/download/dataset',
-    # 'PRODES-INPE','prodes_hydrography',NA,NA,NA,'http://terrabrasilis.dpi.inpe.br/download/dataset',
-    # 'PRODES-INPE','prodes_annual_increase_deforestation',NA,'2008-2020',NA,'http://terrabrasilis.dpi.inpe.br/download/dataset',
-    # 'PRODES-INPE','prodes_cloud',NA,'2016-2020',NA,'http://terrabrasilis.dpi.inpe.br/download/dataset',
-    # 'PRODES-INPE','prodes_not_forest',NA,NA,NA,'http://terrabrasilis.dpi.inpe.br/download/dataset',
-
-
-    ## Auxiliares
-
-    # Estados - http://terrabrasilis.dpi.inpe.br/download/dataset/amz-aux/vector/states_amazon_biome.zip
-    # Limite - http://terrabrasilis.dpi.inpe.br/download/dataset/amz-aux/vector/amazon_border.zip
-    # Municipio Bioma Amazonia - http://terrabrasilis.dpi.inpe.br/download/dataset/amz-aux/vector/municipalities_amazon_biome.zip
-    # Unidade Conservacao - http://terrabrasilis.dpi.inpe.br/download/dataset/amz-aux/vector/conservation_units_amazon_biome.zip
-    # Area Indigena - http://terrabrasilis.dpi.inpe.br/download/dataset/amz-aux/vector/indigeneous_area_amazon_biome.zip
-
-    # DETER (Somente Amazônia Legal e Cerrado)
-
-    # DEGRAD is included here http://www.inpe.br/cra/projetos_pesquisas/deter.php
-
-    # javascript: download('http://terrabrasilis.dpi.inpe.br/file-delivery/download/deter-amz/shape','file-download-1');
-    # javascript: download('http://terrabrasilis.dpi.inpe.br/file-delivery/download/deter-cerrado/shape','file-download-2');
-
-    "DETER-INPE", "deter_amz", NA, NA, NA, "http://terrabrasilis.dpi.inpe.br/file-delivery/download/",
-    "DETER-INPE", "deter_cerrado", NA, NA, NA, "http://terrabrasilis.dpi.inpe.br/file-delivery/download/",
-
-    # DEGRAD
-
-    # "http://www.obt.inpe.br/OBT/assuntos/programas/amazonia/degrad/arquivos/degrad",year,"_final_shp.zip"
-
+    "DETER-INPE", "deter_amz", NA, NA, NA, "http://terrabrasilis.dpi.inpe.br/file-delivery/download/deter-amz/shape",
+    "DETER-INPE", "deter_cerrado", NA, NA, NA, "http://terrabrasilis.dpi.inpe.br/file-delivery/download/deter-cerrado/shape",
     "DEGRAD-INPE", "degrad", NA, "2007-2016", NA, "http://www.obt.inpe.br/OBT/assuntos/programas/amazonia/degrad",
 
     ###############
@@ -933,30 +860,13 @@ datasets_link <- function() {
     "MAPBIOMAS", "mapbiomas_deforestation_regeneration", NA, "1988-2017", "State", "https://mapbiomas-br-site.s3.amazonaws.com/",
     "MAPBIOMAS", "mapbiomas_irrigation", NA, "2000-2019", "State", "https://mapbiomas-br-site.s3.amazonaws.com/",
     "MAPBIOMAS", "mapbiomas_grazing_quality", NA, "2010 & 2018", "State", "https://mapbiomas-br-site.s3.amazonaws.com/",
+    "MAPBIOMAS", "mapbiomas_mining", NA, "1985-2020", "country, state, municipality, biome, indigenous", "https://mapbiomas-br-site.s3.amazonaws.com/",
 
     #############
     ## SIGMINE ##
     #############
 
-    # Agencia Nacional de Mineracao (ANM)
-
-    "ANM-SIGMINE", "sigmine_active", NA, NA, NA, "https://app.anm.gov.br/dadosabertos/",
-
-    # https://dados.gov.br/dataset/sistema-de-informacoes-geograficas-da-mineracao-sigmine
-
-    # Processos minerários ativos - Brasil
-    # https://app.anm.gov.br/dadosabertos/SIGMINE/PROCESSOS_MINERARIOS/BRASIL.zip
-    # Processos minerários inativos - Brasil
-    # https://app.anm.gov.br/dadosabertos/SIGMINE/PROCESSOS_MINERARIOS/BRASIL_INATIVOS.zip
-    # Arrendamentos
-    # https://app.anm.gov.br/dadosabertos/SIGMINE/ARRENDAMENTO.zip
-    # Áreas de proteção de fonte
-    # https://app.anm.gov.br/dadosabertos/SIGMINE/PROTECAO_FONTE.zip
-    # Áreas de bloqueio
-    # https://app.anm.gov.br/dadosabertos/SIGMINE/BLOQUEIO.zip
-    # Reservas garimpeiras
-    # https://app.anm.gov.br/dadosabertos/SIGMINE/RESERVAS_GARIMPEIRAS.zip
-
+    "ANM-SIGMINE", "sigmine_active", NA, NA, NA, "https://app.anm.gov.br/dadosabertos/SIGMINE/PROCESSOS_MINERARIOS/BRASIL.zip",
 
     ##########
     ## SEEG ##
@@ -964,28 +874,19 @@ datasets_link <- function() {
 
     "SEEG", "seeg", NA, NA, "Country, State, Municipality", "http://seeg.eco.br/download",
 
-    # http://seeg.eco.br/download
-
-    # UF - https://seeg-br.s3.amazonaws.com/2019-v7.0/download/1-SEEG8_GERAL-BR_UF_2020.11.05_-_SITE.xlsx
-    # Municipios - https://drive.google.com/drive/folders/1S789njrMQCSJdnEjiOisk6VWy7eFwBfi?usp=sharing
-
     #########
     ## IPS ##
     #########
 
-    #  http://www.ipsamazonia.org.br/assets/IPS_Tabela_Completa-8bb3b841e46c8fb17b0331d8ea92bef3.xlsx
-
-    "IPS", "ips", NA, "2014 and/or 2018 and/or 2021", NA, "http://www.ipsamazonia.org.br",
+    "IPS", "ips", NA, "2014 and/or 2018 and/or 2021", NA, "http://www.ipsamazonia.org.br/assets/IPS_Tabela_Completa-1df30fcea79209e3c7e8634a586f95e6.xlsx",
 
     ###########
     ## IBAMA ##
     ###########
 
-    # There is a lot to map, seem an incredible data source
-
-    "AREAS_EMBARGADAS-IBAMA", "areas_embargadas", NA, NA, "Municipality", "https://servicos.ibama.gov.br/ctf/publico/areasembargadas/downloadListaAreasEmbargadas.php",
-    # http://dadosabertos.ibama.gov.br/organization/instituto-brasileiro-do-meio-ambiente-e-dos-recursos-naturais-renovaveis
-
+    "IBAMA", "areas_embargadas", NA, NA, "Municipality", "https://servicos.ibama.gov.br/ctf/publico/areasembargadas/downloadListaAreasEmbargadas.php",
+    "IBAMA", "distributed_fines", NA, NA, "Municipality", "https://dadosabertos.ibama.gov.br/dados/SICAFI/",
+    "IBAMA", "collected_fines", NA, NA, "Municipality", "https://dadosabertos.ibama.gov.br/dados/SICAFI/",
 
     #################################################################
     ## Other Economics Datasets IBGE - GDP Munic, Employment, Wage ##
@@ -993,27 +894,19 @@ datasets_link <- function() {
 
     ## Municipal GDP ##
 
-    "PIB_MUNIC-IBGE", "pibmunic", "5938", "2002-2018", "Country, State, Municipality", "https://sidra.ibge.gov.br/pesquisa/pib-munic/tabelas",
-
-    ## Estimated Population ##
-
-    # https://sidra.ibge.gov.br/pesquisa/estimapop/tabelas
+    "PIB_MUNIC-IBGE", "pibmunic", "5938", "2002-2020", "Country, State, Municipality", "https://sidra.ibge.gov.br/pesquisa/pib-munic/tabelas",
 
     ## Labor Market Info ##
 
     "CEMPRE-IBGE", "cempre", "6449", "2006-2019", "Country, State, Municipality", "https://sidra.ibge.gov.br/pesquisa/cempre/tabelas",
 
-    ## Demographic Info ##
-
-    # https://sidra.ibge.gov.br/pesquisa/censo-demografico/series-temporais/series-temporais/
-
     ##########
     ## CIPÓ ##
     ##########
 
-    "CIPO", "brazilian_actors", NA, NA, NA, "https://plataformacipo.org/mapa-crimes-ambientais/",
-    "CIPO", "international_cooperation", NA, NA, NA, "https://plataformacipo.org/mapeamento-cooperacao-internacional/",
-    "CIPO", "forest_governance", NA, NA, NA, "https://plataformacipo.org/arranjos-globais-de-governanca-florestal/",
+    "CIPO", "brazilian_actors", NA, NA, NA, "https://docs.google.com/spreadsheets/d/e/2PACX-1vTpRIu-paL_8rtXLpiT-kCTJRa2Tf_jCCPZxZBc3sjCwMHL8mkrhG2eqVeeIdWkxLTUKPru5uYAWG6g/pub?output=csv",
+    "CIPO", "international_cooperation", NA, NA, NA, "https://docs.google.com/spreadsheets/u/0/d/e/2PACX-1vSpyBina4qr3GG-5ZlKW8_fjQwgIP3lq5lxanpO5_bUZenCVFO6N-WrF3bTkpokVzNVpRnob9Jhn8qe/pub?output=csv",
+    "CIPO", "forest_governance", NA, NA, NA, "https://docs.google.com/spreadsheets/u/0/d/e/2PACX-1vTpnO9DEiy1mMRwBI5jAzBbYhFVBlcsX4TNRZyoDYBNUhEPZcLviexaynCJfY3JC-CCBGy00-Fs3jxu/pub?output=csv",
 
     ##################
     ## TerraClimate ##
@@ -1034,34 +927,77 @@ datasets_link <- function() {
     "TerraClimate", "water_evaporation", NA, "1958-2020", "Municipality", "http://thredds.northwestknowledge.net:8080/thredds/ncss",
     "TerraClimate", "palmer_drought_severity_index", NA, "1958-2020", "Municipality", "http://thredds.northwestknowledge.net:8080/thredds/ncss",
 
+    #####################
+    ## Health Datasets ##
+    #####################
+
+    "DATASUS", "datasus_sim_do", NA, "1996-2020", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/SIM/CID10/DORES/",
+    "DATASUS", "datasus_sim_dofet", NA, "1996-2020", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/SIM/CID10/DOFET/",
+    "DATASUS", "datasus_sim_doext", NA, "1996-2020", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/SIM/CID10/DOFET/",
+    "DATASUS", "datasus_sim_doinf", NA, "1996-2020", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/SIM/CID10/DOFET/",
+    "DATASUS", "datasus_sim_domat", NA, "1996-2020", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/SIM/CID10/DOFET/",
+    "DATASUS", "datasus_cnes_lt", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/LT/",
+    "DATASUS", "datasus_cnes_st", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/ST/",
+    "DATASUS", "datasus_cnes_dc", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/DC/",
+    "DATASUS", "datasus_cnes_eq", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/EQ/",
+    "DATASUS", "datasus_cnes_sr", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/SR/",
+    "DATASUS", "datasus_cnes_hb", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/HB/",
+    "DATASUS", "datasus_cnes_pf", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/PF/",
+    "DATASUS", "datasus_cnes_ep", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/EP/",
+    "DATASUS", "datasus_cnes_rc", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/RC/",
+    "DATASUS", "datasus_cnes_in", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/IN/",
+    "DATASUS", "datasus_cnes_ee", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/EE",
+    "DATASUS", "datasus_cnes_ef", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/EF/",
+    "DATASUS", "datasus_cnes_gm", NA, "2005-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/CNES/200508_/Dados/GM/",
+    "DATASUS", "datasus_sih", NA, "2008-2022", "State", "ftp://ftp.datasus.gov.br/dissemin/publicos/SIHSUS/200801_/dados/",
+
+    ##########
+    ## IEMA ##
+    ##########
+
+    "IEMA", "iema", NA, "2018", "Municipality", "https://drive.google.com/uc?export=download&id=10JMRtzu3k95vl8cQmHkVMQ9nJovvIeNl",
+
+    ##########
+    ## SEEG ##
+    ##########
+
+    "SEEG", "seeg_farming", NA, "1970-2019", "Country, State, Municipality", "http://seeg.eco.br/download",
+    "SEEG", "seeg_industry", NA, "1970-2019", "Country, State, Municipality", "http://seeg.eco.br/download",
+    "SEEG", "seeg_energy", NA, "1970-2019", "Country, State, Municipality", "http://seeg.eco.br/download",
+    "SEEG", "seeg_land", NA, "1970-2019", "Country, State, Municipality", "http://seeg.eco.br/download",
+    "SEEG", "seeg_residuals", NA, "1970-2019", "Country, State, Municipality", "http://seeg.eco.br/download",
+
+    ##########
+    ## BACI ##
+    ##########
+
+    "BACI", "HS92", NA, "1995-2020", "Country", "http://www.cepii.fr/DATA_DOWNLOAD/baci/data/BACI_HS92_V202201.zip",
+
+    ############
+    ## IMAZON ##
+    ############
+
+    "Imazon", "imazon_shp", NA, "2020", "Municipality", "https://docs.google.com/uc?export=download&id=1JHc2J_U8VXHVuWVsi8wVBnNzZ37y1ehv",
+
+    #########
+    ## EPE ##
+    #########
+
+    "EPE", "energy_consumption_per_class", NA, "2004-2021", "Region, Subsystem, State", "https://www.epe.gov.br/sites-pt/publicacoes-dados-abertos/publicacoes/Documents/CONSUMO%20MENSAL%20DE%20ENERGIA%20EL%c3%89TRICA%20POR%20CLASSE.xls",
+    "EPE", "national_energy_balance", NA, "2011-2022", "Region, Municipality", "https://drive.google.com/file/d/1_JTYyAPdbQayR-nrURts6OmbKcm2cLix/view?usp=share_link",
+
+    ###########
+    ## ANEEL ##
+    ###########
+
+    "ANEEL", "energy_development_budget", NA, "2013-2022", NA, "https://drive.google.com/file/d/1h7mu-9qbKfISk1-k4JSrBhXKBMQHTOH9/view?usp=share_link",
+    "ANEEL", "energy_generation", NA, "1908-2021", "Municipality", "https://git.aneel.gov.br/publico/centralconteudo/-/raw/main/relatorioseindicadores/geracao/BD_SIGA.xlsx?inline=false",
+
     ## Shapefile from github repository
 
-    "Internal", "geo_municipalities", NA, "2020", "Municipality", "https://raw.github.com/datazoompuc/datazoom.amazonia/master/data-raw/geo_municipalities.rds"
+
+    "Internal", "geo_municipalities", NA, "2020", "Municipality", "https://raw.github.com/datazoompuc/datazoom.amazonia/master/data-raw/geo_municipalities.rds",
   )
 
   return(link)
 }
-
-datasets_seeg <- function() {
-
-  ## Add file type at the end in order to set the Curl Process
-
-  link <- tibble::tribble(
-    ~survey, ~dataset, ~id_code, ~link,
-    "SEEG", "seeg_farming", 100, "http://seeg.eco.br/download",
-    "SEEG", "seeg_industry", 101, "http://seeg.eco.br/download",
-    "SEEG", "seeg_energy", 102, "http://seeg.eco.br/download",
-    "SEEG", "seeg_land", 103, "http://seeg.eco.br/download",
-    "SEEG", "seeg_residuals", 104, "http://seeg.eco.br/download",
-  )
-  return(link)
-}
-
-
-datasets_baci <- function() {
-  link <- tibble::tribble(
-    ~survey, ~dataset, ~available_time, ~link,
-    "BACI", "HS92", "1995-2020", "http://www.cepii.fr/DATA_DOWNLOAD/baci/data",
-  )
-  return(link)
-}
