@@ -1,64 +1,49 @@
 #' @title PEVS - Forestry Activities
 #'
-#' @description Loads information on the amount and value of the production of the exploitation of native plant resources and planted forest massifs, as well as existing total and harvested areas of forest crops. Survey is done at the municipal level and data is available from 1986 to 2020. See \url{https://www.ibge.gov.br/en/statistics/economic/agriculture-forestry-and-fishing/18374-forestry-activities.html?=&t=o-que-e}
+#' @description Loads information on the amount and value of the production of the exploitation of native plant resources and planted forest massifs, as well as existing total and harvested areas of forest crops.
 #'
 #' @param dataset A dataset name ("pevs_forest_crops", "pevs_silviculture" or "pevs_silviculture_area"). You can also use SIDRA codes (see \url{https://sidra.ibge.gov.br/pesquisa/pevs/quadros/brasil/2019})
-#' @param raw_data A \code{boolean} setting the return of raw (\code{TRUE}) or processed (\code{FALSE}) data.
-#' @param geo_level A \code{string} that defines the geographic level of the data. Can be one of "country", "region", "state", "mesoregion", "microregion" or "city". See documentation of \code{sidrar}.
-#' @param time_period A \code{numeric} indicating what years will the data be loaded in the format YYYY. Can be a sequence of numbers such as 2010:2012.
-#' @param language A \code{string} that indicates in which language the data will be returned. Currently, only Portuguese ("pt") and English ("eng") are supported. Defaults to "eng".
+#' @inheritParams load_baci
+#' @param geo_level A \code{string} that defines the geographic level of the data. Can be one of "country", "region", "state", or "municipality".
 #'
 #' @return A \code{tibble} consisting of geographic units that present positive values for any of the variables in the dataset.
 #'
-#' @encoding UTF-8
-#'
-#' @export
-#'
 #' @examples \dontrun{
-#' # download state raw data from 2012 for silviculture
-#' pevs_silvi <- load_pevs(
+#' # Download treated (raw_data = FALSE) silviculture data (dataset = 'pevs_silviculture')
+#' # by state (geo_level = 'state') from 2012 (time_period =  2012)
+#' # in portuguese (language = "pt")
+#' data <- load_pevs(
 #'   dataset = "pevs_silviculture",
-#'   raw_data = TRUE,
+#'   raw_data = FALSE,
 #'   geo_level = "state",
-#'   time_period = 2012
+#'   time_period = 2012,
+#'   language = "pt"
+#' )
+#'
+#' # Download raw (raw_data = TRUE) forest crops data by region from 2012 to 2013 in english
+#' data <- load_pevs(
+#'   dataset = "pevs_forest_crops",
+#'   raw_data = TRUE,
+#'   geo_level = "region",
+#'   time_period = 2012:2013
 #' )
 #' }
-load_pevs <- function(dataset = NULL, raw_data,
+#'
+#' @export
+
+load_pevs <- function(dataset, raw_data = FALSE,
                       geo_level, time_period,
                       language = "eng") {
 
-  ## Translation is only made through collapsing at the end
-  # - What if we wanted to deliver raw data?
-
-  ## To-Dos:
-  ## Include Progress Bar
-  ## Include Labels
-  ## Support for Raw Downloads
-  ## Write Vignettes
-
   ##############################
   ## Binding Global Variables ##
   ##############################
 
-  sidra_code <- NULL
-  nivel_territorial_codigo <- NULL
-  nivel_territorial <- NULL
-  unidade_de_medida_codigo <- NULL
-  unidade_de_medida <- NULL
-  tipo_de_produto_codigo <- NULL
-  variavel_codigo <- NULL
-  ano_codigo <- NULL
-  valor <- NULL
-  tipo_de_produto_extrativo_codigo <- NULL
-  tipo_de_produto_da_silvicultura_codigo <- NULL
-  tipo_de_produto_da_silvicultura <- NULL
-  especie_florestal_codigo <- NULL
-  especie_florestal <- NULL
-  geo_id <- NULL
-  ano <- NULL
-  variavel <- NULL
-  tipo_de_produto <- NULL
-  tipo_de_produto_extrativo <- NULL
+  sidra_code <- nivel_territorial_codigo <- nivel_territorial <- unidade_de_medida_codigo <- NULL
+  unidade_de_medida <- tipo_de_produto_codigo <- variavel_codigo <- ano_codigo <- NULL
+  valor <- tipo_de_produto_extrativo_codigo <- tipo_de_produto_da_silvicultura_codigo <- NULL
+  tipo_de_produto_da_silvicultura <- especie_florestal_codigo <- especie_florestal <- NULL
+  geo_id <- ano <- variavel <- tipo_de_produto <- tipo_de_produto_extrativo <- NULL
   available_time <- vars <- NULL
 
   #############################
@@ -70,6 +55,7 @@ load_pevs <- function(dataset = NULL, raw_data,
   param$geo_level <- geo_level
   param$time_period <- time_period
   param$language <- language
+  param$raw_data <- raw_data
 
   if (!is.numeric(param$dataset)) {
     param$code <- datasets_link() %>%
@@ -99,14 +85,8 @@ load_pevs <- function(dataset = NULL, raw_data,
     stop("Provided time period greater than supported. Check documentation for time availability.")
   }
 
-
-
   ## Dataset
 
-  if (is.null(param$dataset)) {
-    stop("Missing Dataset!")
-  }
-
   if (param$code == 289) {
     param$data_name <- "Vegetal extraction quantity and value (Quantidade e valor da extracao vegetal)"
   }
@@ -137,11 +117,10 @@ load_pevs <- function(dataset = NULL, raw_data,
 
   ## Return Raw Data
 
-  if (raw_data == TRUE) {
+  if (param$raw_data) {
     return(dat)
   }
 
-
   ######################
   ## Data Enginnering ##
   ######################
